==> accounts_management-0.1.6.gem: app/controllers/accounts_management/accounts/bank_accounts_controller.rb <==
require_dependency "accounts_management/accounts_management_controller"

module AccountsManagement
  class Accounts::BankAccountsController < AccountsManagementController
    # GET /accounts/bank_accounts
    # GET /accounts/bank_accounts.json
    def index
      @accounts_bank_accounts = Accounts::BankAccount.all
  
      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @accounts_bank_accounts }
      end
    end
  
    # GET /accounts/bank_accounts/1
    # GET /accounts/bank_accounts/1.json
    def show
      @accounts_bank_account = Accounts::BankAccount.find(params[:id])
  
      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @accounts_bank_account }
      end
    end
  
    # GET /accounts/bank_accounts/new
    # GET /accounts/bank_accounts/new.json
    def new
      @accounts_bank_account = Accounts::BankAccount.new
  
      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @accounts_bank_account }
      end
    end
  
    # GET /accounts/bank_accounts/1/edit
    def edit
      @accounts_bank_account = Accounts::BankAccount.find(params[:id])
    end
  
    # POST /accounts/bank_accounts
    # POST /accounts/bank_accounts.json
    def create
      @accounts_bank_account = Accounts::BankAccount.new(params[:accounts_bank_account])
  
      respond_to do |format|
        if @accounts_bank_account.save
          format.html { redirect_to @accounts_bank_account, :notice => 'Bank account was successfully created.' }
          format.json { render :json => @accounts_bank_account, :status => :created, :location => @accounts_bank_account }
        else
          format.html { render :action => "new" }
          format.json { render :json => @accounts_bank_account.errors, :status => :unprocessable_entity }
        end
      end
    end
  
    # PUT /accounts/bank_accounts/1
    # PUT /accounts/bank_accounts/1.json
    def update
      @accounts_bank_account = Accounts::BankAccount.find(params[:id])
  
      respond_to do |format|
        if @accounts_bank_account.update_attributes(params[:accounts_bank_account])
          format.html { redirect_to @accounts_bank_account, :notice => 'Bank account was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @accounts_bank_account.errors, :status => :unprocessable_entity }
        end
      end
    end
  
    # DELETE /accounts/bank_accounts/1
    # DELETE /accounts/bank_accounts/1.json
    def destroy
      @accounts_bank_account = Accounts::BankAccount.find(params[:id])
      @accounts_bank_account.destroy
  
      respond_to do |format|
        format.html { redirect_to accounts_bank_accounts_url }
        format.json { head :no_content }
      end
    end
  end
end

==> accounts_management-0.1.7.gem: app/controllers/accounts_management/accounts/bank_accounts_controller.rb <==
require_dependency "accounts_management/accounts_management_controller"

module AccountsManagement
  class Accounts::BankAccountsController < AccountsManagementController
    # GET /accounts/bank_accounts
    # GET /accounts/bank_accounts.json
    def index
      @accounts_bank_accounts = Accounts::BankAccount.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render json: @accounts_bank_accounts }
      end
    end

    # GET /accounts/bank_accounts/1
    # GET /accounts/bank_accounts/1.json
    def show
      @accounts_bank_account = Accounts::BankAccount.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render json: @accounts_bank_account }
      end
    end

    # GET /accounts/bank_accounts/new
    # GET /accounts/bank_accounts/new.json
    def new
      @accounts_bank_account = Accounts::BankAccount.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render json: @accounts_bank_account }
      end
    end

    # GET /accounts/bank_accounts/1/edit
    def edit
      @accounts_bank_account = Accounts::BankAccount.find(params[:id])
    end

    # POST /accounts/bank_accounts
    # POST /accounts/bank_accounts.json
    def create
      @accounts_bank_account = Accounts::BankAccount.new(params[:accounts_bank_account])

      respond_to do |format|
        if @accounts_bank_account.save
          format.html { redirect_to @accounts_bank_account, notice: 'Bank account was successfully created.' }
          format.json { render json: @accounts_bank_account, status: :created, location: @accounts_bank_account }
        else
          format.html { render action: "new" }
          format.json { render json: @accounts_bank_account.errors, status: :unprocessable_entity }
        end
      end
    end

    # PUT /accounts/bank_accounts/1
    # PUT /accounts/bank_accounts/1.json
    def update
      @accounts_bank_account = Accounts::BankAccount.find(params[:id])

      respond_to do |format|
        if @accounts_bank_account.update_attributes(params[:accounts_bank_account])
          format.html { redirect_to @accounts_bank_account, notice: 'Bank account was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render action: "edit" }
          format.json { render json: @accounts_bank_account.errors, status: :unprocessable_entity }
        end
      end
    end

    # DELETE /accounts/bank_accounts/1
    # DELETE /accounts/bank_accounts/1.json
    def destroy
      @accounts_bank_account = Accounts::BankAccount.find(params[:id])
      @accounts_bank_account.destroy

      respond_to do |format|
        format.html { redirect_to accounts_bank_accounts_url }
        format.json { head :no_content }
      end
    end
  end
end
